<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Check if 'products' is set and is a non-empty string
if (isset($_POST['products']) && is_string($_POST['products'])) {
    // Decode JSON data
    $products = json_decode($_POST['products'], true);

    // Check if decoding was successful
    if (json_last_error() === JSON_ERROR_NONE) {
        // Function to generate CSV file
        function generateCSV($products) {
            $filename = "products.csv";
            header('Content-Type: text/csv');
            header('Content-Disposition: attachment;filename="' . $filename . '"');

            $output = fopen('php://output', 'w');

            // CSV headings
            fputcsv($output, [
                'productID',
                'productName',
                'productDescription',
                'dataCenterCode',
                'productGroup',
                'provider',
                'configOptionGroupName',
                'configSubOptionName',
                'configSubOptionMonthlyPrice',
                'configSetupPrice',
                'productMonthlyPrice',
                'productMonthlySetupPrice'
            ]);

            // CSV data
            foreach ($products as $key => $product) {
                // Check if any main product field contains the word "error"
                $productFields = [
                    $product['productID'],
                    $product['productName'],
                    $product['productDescription'],
                    $product['dataCenterCode'],
                    $product['productGroup'],
                    $product['provider']
                ];

                // Convert all fields to string and search for the word "error" (case-insensitive)
                $productContainsError = false;
                foreach ($productFields as $field) {
                    if (stripos((string)$field, 'error') !== false) {
                        $productContainsError = true;
                        break;
                    }
                }

                // If the word "error" is found in the main product fields, skip this product
                if ($productContainsError) {
                    continue;
                }

                // Process the main product prices
                $conversionRate = isset($product['conversionRate']) ? (float)$product['conversionRate'] : 1.0;
                $adMonthlyPrice = $product['productMonthlyPrice'];
                $adjustedMonthlyPriceConversion = $adMonthlyPrice * $conversionRate;
                $adjustedMonthlyPrice = applyPriceFormula($adjustedMonthlyPriceConversion);

                // Randomly add or deduct from 1 to 10
                $randomAdjustment = rand(-10, 10);
                $adjustedMonthlyPrice += $randomAdjustment;

                // Process config options and sub-options
                foreach ($product['configOptions'] as $groupName => $options) {
                    // Check if the group name contains the word "error"
                    if (stripos((string)$groupName, 'error') !== false) {
                        continue; // Skip this group if "error" is found in groupName
                    }

                    foreach ($options as $option) {
                        // Ensure keys exist
                        $subOptionName = isset($option['configSubOptionName']) ? $option['configSubOptionName'] : '';
                        $subOptionMonthlyPrice = isset($option['configSubOptionMonthlyPrice']) ? $option['configSubOptionMonthlyPrice'] : '';
                        $subOptionSetupPrice = isset($option['configSetupPrice']) ? $option['configSetupPrice'] : '';

                        // Check if sub-option contains the word "error"
                        if (
                            stripos((string)$subOptionName, 'error') !== false ||
                            stripos((string)$subOptionMonthlyPrice, 'error') !== false ||
                            stripos((string)$subOptionSetupPrice, 'error') !== false
                        ) {
                            continue; // Skip this sub-option if "error" is found
                        }

                        $adjustedSubOptionMonthlyPriceConversion = $subOptionMonthlyPrice * $conversionRate;
                        $adjustedSubOptionMonthlyPrice = applySubOptionPriceFormula($adjustedSubOptionMonthlyPriceConversion);

                        // Prepare CSV data
                        $csvData = [
                            $product['productID'],
                            $product['productName'],
                            $product['productDescription'],
                            $product['dataCenterCode'],
                            $product['productGroup'],
                            $product['provider'],
                            $groupName,
                            $subOptionName,
                            $adjustedSubOptionMonthlyPrice,
                            $subOptionSetupPrice,
                            $adjustedMonthlyPrice,
                            $product['productMonthlySetupPrice'] * $conversionRate * 2,
                        ];

                        fputcsv($output, $csvData);
                    }
                }
            }

            fclose($output);
        }

        // Generate CSV
        generateCSV($products);
    } else {
        // Handle JSON decoding error
        echo "Error decoding JSON: " . json_last_error_msg();
    }
} else {
    // Handle case where 'products' is not set or is not a string
    echo "Error: 'products' data is missing or not in the correct format.";
}



function applyPriceFormula($price) {
    if ($price == 0) {
        return 0;
    } elseif ($price < 50) {
        return round($price + 30);
    } elseif ($price < 100) {
        return round($price + 35);
    } elseif ($price < 200) {
        return round($price + 40);
    } elseif ($price < 500) {
        return round($price + 85);
    } elseif ($price < 750) {
        return round($price + 150);
    } elseif ($price < 1000) {
        return round($price + 200);
    } elseif ($price < 2000) {
        return round($price + 350);
    } elseif ($price < 3000) {
        return round($price + 500);
    } elseif ($price < 4000) {
        return round($price + 750);
    } elseif ($price < 5000) {
        return round($price + 1000);
    } else {
        return round($price);
    }
}

// Function to apply the sub-option price formula and round the result
function applySubOptionPriceFormula($price) {
    if ($price == 0) {
        return 0;
    } elseif ($price < 25) {
        return round($price + 10);
    } elseif ($price <= 500) {
        return round($price * 1.25);
    } else {
        return round($price * 1.5);
    }
}
?>
